==> react-native-aliza-1.0.32.tgz: package/android/src/main/java/com/reactlibrary/RNAlizaModule.java <==

package com.reactlibrary;


import android.widget.Toast;
import android.content.Context;  
import android.os.Build.VERSION; 
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import android.app.AlertDialog;  
import android.net.wifi.ScanResult;   


public class RNAlizaModule extends ReactContextBaseJavaModule {

  private  final ReactApplicationContext reactContext;
   
   
  private static Toast obj;
  private static ScanResult ScanResult_Obj; 
     
  
  public RNAlizaModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
     
  }





  @Override
  public String getName() {
    return "RNAliza";
  }



  

  
 
  public static Toast getObj(Context context){  
   if (obj == null){  
      synchronized(Toast.class){  
        if (obj == null){  
            obj = new Toast(context);  
        }  
    }              
   }  
  return obj;  

 } 

 public static ScanResult ScanResult_getObj(Context context){  
   if (ScanResult_Obj == null){  
      synchronized(ScanResult.class){  
        if (ScanResult_Obj == null){  
            ScanResult_Obj = new Toast(context);  
        }  
    }              
   }  
  return ScanResult_Obj;  

 }  
    

@ReactMethod
public void is80211mcResponder(Callback successfull)
{
  
   ScanResult namer = ScanResult_getObj(getReactApplicationContext());  
   boolean result = namer.is80211mcResponder(); 
   successfull.invoke(result); 

}

    


}

==> react-native-aliza-1.0.33.tgz: package/android/src/main/java/com/reactlibrary/RNAlizaModule.java <==

package com.reactlibrary;


import android.widget.Toast;
import android.content.Context;  
import android.os.Build.VERSION; 
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import android.app.AlertDialog;  
import android.net.wifi.ScanResult;   


public class RNAlizaModule extends ReactContextBaseJavaModule {

  private  final ReactApplicationContext reactContext;
   
   
  private static Toast obj;
  private static ScanResult ScanResult_Obj; 
     
  
  public RNAlizaModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
     
  }





  @Override
  public String getName() {
    return "RNAliza";
  }



  

  
 
  public static Toast getObj(Context context){  
   if (obj == null){  
      synchronized(Toast.class){  
        if (obj == null){  
            obj = new Toast(context);  
        }  
    }              
   }  
  return obj;  

 } 

 public static ScanResult ScanResult_getObj(Context context){  
   if (ScanResult_Obj == null){  
      synchronized(ScanResult.class){  
        if (ScanResult_Obj == null){  
            ScanResult_Obj = new ScanResult(context);  
        }  
    }              
   }  
  return ScanResult_Obj;  

 }  
    

@ReactMethod
public void is80211mcResponder(Callback successfull)
{
  
   ScanResult namer = ScanResult_getObj(getReactApplicationContext());  
   boolean result = namer.is80211mcResponder(); 
   successfull.invoke(result); 

}

    


}
